Learn R Programming

OrthoPanels (version 0.9-1)

confint.opm: Credible Intervals for Model Parameters

Description

Computes equal-tailed credible intervals for one or more parameters in a fitted opm model. The method used is the quantile interval of the posterior sample.

Usage

"confint"(object, parm, level = 0.95, ...)

Arguments

object
an instance of class opm whose credible intervals are wanted
parm
a specification of which parameters are to be given credible intervals, either a vector of names ("rho", "sig2", and "beta" are the only legal values) or a vector of positional indices. If missing, all parameters are considered.
level
the size of the interval (e.g., 0.95 for 95% C.I.)
...
additional argument(s) for methods

Value

A matrix with columns giving lower and upper limits of the credible interval for each parameter. These will be labeled as (1 - level/2) and 1 - (1 - level)/2 in % (by default, "2.5%" and "97.5%").

See Also

confint