opm Objecthist applied to opm objects.
Each parameter will be plotted in a separate figure.
"hist"(x, parm, ask = dev.interactive(), plot = TRUE, main = NULL, xlab = NULL, ...)opmrho", "sig2"
and "beta" are the only legal values) or a vector of positional
indices. If missing, all parameters are considered.TRUE", and the R session is interactive, the
user is asked to press a key before a new figure (i.e., histogram
of the next model parameter) is drawn.TRUE" (default), the resulting object of
class "histogram" is plotted by plot.hist.hist
function operating on the individual parameter's sampleshistogram", one for each
requested model parameter. The elements are named after the
parameter.