Learn R Programming

OrthoPanels (version 0.9-1)

p_rho: Returns the posterior density $p(\rho|\Theta)$

Description

Returns the posterior density $p(\rho|\Theta)$

Usage

p_rho(x, y, rho, log.p = FALSE)

Arguments

x
an array of dimension time x variable x case of terms.
y
a matrix of dimension time x case of responses.
rho
vector of quantiles.
log.p
if TRUE, probabilities are given as log(p).