opm(), which implements the
orthogonal reparameterization approach recommended by Lancaster
(2002) to estimate dynamic panel models with fixed effects (and
optionally: panel specific intercepts). The OLS estimator for such
models is biased with a fixed (small) $N$ (Nickell 1981). Equivalently,
a maximum likelihood estimation leads to an incidental parameters
problem (Neyman and Scott 1948; Lancaster 2000). The approach by
Lancaster (2002) uses an orthogonal reparameterization of the fixed
effects to produce a likelihood-based estimator of the remaining
parameters that is exact and consistent as $N$ approaches infinity
for $T$ greater than or equal to 2.
Lancaster, T. (2002) Orthogonal parameters and panel data. Review of Economic Studies, 69, 647--666.
Neyman, J. and Scott, E. L. (1948) Consistent estimation from partially consistent observations. Econometrica, 16, 1--32.
Nickell, S. (1981) Biases in dynamic models with fixed effects. Econometrica, 49, 1417--1426.